@@ -5,15 +5,18 @@ use v5.10.1;
 use strict;
 use warnings;
 
-use Exporter qw/ import /;
+{
+    use version 0.77;
+    $Pod::Readme::Types::VERSION = version->declare('v1.0.1_02');
+}
+
+use Exporter::Lite;
 use IO qw/ Handle /;
 use Path::Class;
 use Scalar::Util qw/ blessed /;
 use Type::Tiny;
 use Types::Standard qw/ FileHandle Str /;
 
-use version 0.77; our $VERSION = version->declare('v1.0.1_01');
-
 our @EXPORT_OK =
   qw/ Dir File Indentation IO ReadIO WriteIO HeadingLevel TargetName /;
 
