@@ -2,19 +2,21 @@ package Pod::Readme::Test;
 
 use Exporter::Lite;
 use IO::String;
-use Test::Most;
+
+require Test::More;
 
 our $out;
 our $io = IO::String->new($out);
 our $prf;
 
-our @EXPORT = qw/ $prf $out $io filter_lines reset_out /;
+our @EXPORT    = qw/ $prf $out $io filter_lines reset_out /;
+our @EXPORT_OK = @EXPORT;
 
 sub filter_lines {
     my @lines = @_;
     foreach my $line (@lines) {
-        note $line if $line =~ /^=(?:\w+)/;
-        $prf->filter_line($line . "\n");
+        Test::More::note $line if $line =~ /^=(?:\w+)/;
+        $prf->filter_line( $line . "\n" );
     }
 }
 
