@@ -15,8 +15,10 @@ include 'File::Temp' => {
     import => [qw/ tempfile /],
 };
 
+# TODO: will this still work on Windows?
+
 include 'File::Compare' => {
-    import => [qw/ compare /],
+    import => [qw/ compare_text /],
 };
 
 include 'Path::Class';
